@@ -1,11 +1,8 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
-from awlsim.core.compat import *
+from awlsim.common.compat import *
 
 from awlsim.core.main import *
 from awlsim.core.cpu import *
 from awlsim.core.hardware import *
 from awlsim.core.parser import *
-from awlsim.core.project import *
 from awlsim.core.util import *
-from awlsim.core.version import *
-from awlsim.core.templates import *
