@@ -19,14 +19,14 @@
 #
 
 from __future__ import division, absolute_import, print_function, unicode_literals
-from awlsim.core.compat import *
+from awlsim.common.compat import *
 
 #from awlsim.core.instructions.all_insns cimport * #@cy
 
+from awlsim.common.cpuspecs import *
 from awlsim.core.util import *
 from awlsim.core.instructions.all_insns import * #@nocy
 from awlsim.core.parser import *
-from awlsim.core.cpuspecs import *
 
 
 class AwlInsnTranslator(object):
