@@ -20,13 +20,13 @@
 #
 
 from __future__ import division, absolute_import, print_function, unicode_literals
-from awlsim.core.compat import *
+from awlsim.common.compat import *
+
+from awlsim.common.cpuspecs import *
+from awlsim.common.project import *
+from awlsim.common.datatypehelpers import *
 
 from awlsim.coreserver.memarea import *
-from awlsim.core.util import *
-from awlsim.core.datatypehelpers import *
-from awlsim.core.cpuspecs import *
-from awlsim.core.project import *
 
 import struct
 import socket
