@@ -20,18 +20,18 @@
 #
 
 from __future__ import division, absolute_import, print_function, unicode_literals
-from awlsim.core.compat import *
+from awlsim.common.compat import *
+
+from awlsim.common.subprocess import *
+from awlsim.common.cpuspecs import *
 
 from awlsim.core.main import *
 from awlsim.core.parser import *
-from awlsim.core.cpuspecs import *
 
 from awlsim.coreserver.messages import *
-from awlsim.coreserver.subprocess_wrapper import *
 
 import sys
 import os
-import distutils.spawn
 import select
 import signal
 import socket
@@ -122,10 +122,6 @@ class AwlSimServer(object):
 				pass
 		return result
 
-	@classmethod
-	def findExecutable(cls, executable):
-		return distutils.spawn.find_executable(executable)
-
 	@classmethod
 	def start(cls, listenHost, listenPort,
 		  forkInterpreter=None,
@@ -146,25 +142,23 @@ class AwlSimServer(object):
 
 		if forkServerProcess:
 			# Fork a new server process.
-			proc = cls.findExecutable(forkServerProcess)
+			proc = findExecutable(forkServerProcess)
 			printInfo("Forking server process '%s'" % proc)
 			if not proc:
 				raise AwlSimError("Failed to run executable '%s'" %\
 						  forkServerProcess)
 			serverProcess = PopenWrapper([proc],
-						     env = env,
-						     shell = False)
+						     env = env)
 			return serverProcess
 		elif forkInterpreter:
 			# Fork a new interpreter process and run server.py as module.
-			interp = cls.findExecutable(forkInterpreter)
+			interp = findExecutable(forkInterpreter)
 			printInfo("Forking awlsim core server with interpreter '%s'" % interp)
 			if not interp:
 				raise AwlSimError("Failed to find interpreter "
 						  "executable '%s'" % forkInterpreter)
 			serverProcess = PopenWrapper([interp, "-m", "awlsim.coreserver.server"],
-						     env = env,
-						     shell = False)
+						     env = env)
 			return serverProcess
 		else:
 			# Do not fork. Just run the server in this process.
