@@ -20,7 +20,9 @@
 #
 
 from __future__ import division, absolute_import, print_function, unicode_literals
-from awlsim.core.compat import *
+from awlsim.common.compat import *
+
+from awlsim.common.templates import *
 
 from awlsim.gui.util import *
 from awlsim.gui.sourcetabs import *
@@ -88,10 +90,6 @@ class ProjectWidget(QTabWidget):
 	def __init__(self, parent=None):
 		QTabWidget.__init__(self, parent)
 
-		self.__project = Project(None) # Empty project
-		self.__isAdHocProject = False
-		self.__warnedFileBacked = False
-
 		self.awlTabs = AwlSourceTabWidget(self)
 		self.symTabs = SymSourceTabWidget(self)
 
@@ -100,6 +98,8 @@ class ProjectWidget(QTabWidget):
 		self.setTabToolTip(0, "Enter your AWL/STL program here")
 		self.setTabToolTip(1, "Enter your symbol table here")
 
+		self.reset()
+
 		self.awlTabs.sourceChanged.connect(self.codeChanged)
 		self.symTabs.sourceChanged.connect(self.symTabChanged)
 		self.awlTabs.visibleLinesChanged.connect(self.visibleLinesChanged)
@@ -127,6 +127,13 @@ class ProjectWidget(QTabWidget):
 		"Returns a list of SymTabSource()s"
 		return self.symTabs.getSources()
 
+	def reset(self):
+		self.__project = Project(None) # Empty project
+		self.__isAdHocProject = False
+		self.__warnedFileBacked = False
+		self.awlTabs.reset()
+		self.symTabs.reset()
+
 	def __loadProject(self, project):
 		self.__project = project
 		self.awlTabs.setSources(self.__project.getAwlSources())
